# -*- mode: python; encoding: utf-8; -*-
#
#   Copyright 2013 Thadeu Lima de Souza Cascardo <cascardo@cascardo.info>
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#   You should have received a copy of the GNU General Public License
#   along with this program.  If not, see <http://www.gnu.org/licenses/>.

import baseui
import contribuinte
import ocupacoes
import rendimentoPJ
import sys

class OcupacaoForm(baseui.OptionsForm):
    def __init__(self, ocupacoes, contribuinte):
        g = ocupacoes.groups()
        l = []
        for i in sorted(g):
            l.extend(g[i])
        o = map(lambda x: (x[0], x[3]), l)
        baseui.OptionsForm.__init__(self, u"Ocupações", o, contribuinte.get_campo_contribuinte("ocupacaoPrincipal"))
        self.ocupacoes = ocupacoes
        self.contribuinte = contribuinte
    def set_value(self, value):
        baseui.OptionsForm.set_value(self, value)
        self.contribuinte.set_campo_contribuinte("ocupacaoPrincipal", value)

class ContribuinteForm(baseui.StringForm):
    def __init__(self, name, attr, contribuinte):
        self.contribuinte = contribuinte
        self.attr = attr
        baseui.StringForm.__init__(self, name, self.contribuinte.get_campo_contribuinte(self.attr))
    def set_value(self, value):
        baseui.StringForm.set_value(self, value)
        self.contribuinte.set_campo_contribuinte(self.attr, value)

class AttrForm(baseui.StringForm):
    def __init__(self, name, attr, element):
        self.element = element
        self.attr = attr
        baseui.StringForm.__init__(self, name, self.element.get_attr(self.attr))
    def set_value(self, value):
        baseui.StringForm.set_value(self, value)
        self.element.set_attr(self.attr, value)

def RendimentoPJ(UI, rend):
    form = []
    form.append(AttrForm("Nome", "nomeFontePagadora", rend))
    form.append(AttrForm("CNPJ", "NIFontePagadora", rend))
    form.append(AttrForm("Rendimentos", "rendRecebidoPJ", rend))
    form.append(AttrForm(u"Previdência", "contribuicaoPrevOficial", rend))
    form.append(AttrForm("Imposto Retido", "impostoRetidoFonte", rend))
    form.append(AttrForm(u"Décimo Terceiro", "decimoTerceiro", rend))
    UI.form(form)
    return True

def List(UI, L, Edit, display):
    exit = False
    while not exit:
        ls = []
        for i in L.items:
            ls.append(i.get_attr(display))
        r = UI.list(ls)
        if r[1] == None:
            exit = True
        elif r[1] == 'add':
            Edit(UI, L.new_item())
        elif r[1] == 'edit':
            Edit(UI, L.items[r[0] - 1])
        elif r[1] == 'delete':
            L.remove_item(r[0] - 1)
    return True

def RendimentosPJ(UI, contrib):
    rend = rendimentoPJ.RendimentosPJ(contrib)
    return List(UI, rend, RendimentoPJ, "nomeFontePagadora")

def DadosPessoais(UI, contrib):
    form = []
    ocup = ocupacoes.Ocupacoes()
    form.append(ContribuinteForm("Nome", "nome", contrib))
    form.append(OcupacaoForm(ocup, contrib))
    for i in contribuinte.contribuinte_attributes:
        form.append(ContribuinteForm(i, i, contrib))
    UI.form(form)
    return True

def menu(UI, contrib):
    m = [ "Sair", "Dados Pessoais", "Rendimentos PJ" ]
    f = [ None, DadosPessoais, RendimentosPJ ]
    exit = False
    while not exit:
        r = UI.menu(m)
        if r <= 0:
            exit = True
        else:
            f[r](UI, contrib)

def main():
    ret = False
    UI = baseui.BaseUI()
    while ret == False:
        cpf = UI.get_string("Digite seu CPF: ")
        try:
            contrib = contribuinte.Contribuinte(cpf)
            ret = menu(UI, contrib)
        except RuntimeError, e:
            print "CPF invalido"

if __name__ == '__main__':
    main()

# vim:tabstop=4:expandtab:smartindent
